@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-__version__='0.2.70'
+__version__='0.3.0'
 last_update='2022-11-16'
 author='Damien Marsic, damien.marsic@aliyun.com'
 
@@ -619,32 +619,3 @@ def transl(seq):
     x=''.join([gcode.get(seq[3*i:3*i+3],'X') for i in range(len(seq)//3)])
     return x
 
-
-
-###############################################
-
-fname='toto.csv'
-dic=True
-header=False
-print(csv_read(fname,dic,header))
-
-
-print(intorfloat('1.0'))
-print(intorfloat('10a'))
-print(intorfloat('.10'))
-print(intorfloat('1.0'))
-print(intorfloat('1.0'))
-
-
-
-
-
-
-
-
-
-
-
-
-
-
